@@ -123,18 +123,18 @@ setOldClass("recipe")
 setOldClass(c("terms", "formula"))
 
 
-setClass("Terms",
+setClass("ModelTerms",
   contains = "terms"
 )
 
 
-DesignTerms <- setClass("DesignTerms",
-  contains = "Terms"
+ModelDesignTerms <- setClass("ModelDesignTerms",
+  contains = "ModelTerms"
 )
 
 
-FormulaTerms <- setClass("FormulaTerms",
-  contains = "Terms"
+ModelFormulaTerms <- setClass("ModelFormulaTerms",
+  contains = "ModelTerms"
 )
 
 
@@ -149,6 +149,21 @@ setClass("ModeledInput",
 )
 
 
+setClass("ModeledTerms",
+  contains = c("ModeledInput", "ModelTerms")
+)
+
+
+setClass("ModeledDesignTerms",
+  contains = c("ModeledTerms", "ModelDesignTerms")
+)
+
+
+setClass("ModeledFormulaTerms",
+  contains = c("ModeledTerms", "ModelFormulaTerms")
+)
+
+
 setClass("ModeledFrame",
   contains = c("ModeledInput", "ModelFrame")
 )
@@ -171,21 +186,11 @@ setClass("SelectedModelFrame",
 )
 
 
-setClass("SelectedModeledFrame",
-  contains = c("SelectedInput", "ModelFrame")
-)
-
-
 setClass("SelectedModelRecipe",
   contains = c("SelectedInput", "ModelRecipe")
 )
 
 
-setClass("SelectedModeledRecipe",
-  contains = c("SelectedInput", "ModelRecipe")
-)
-
-
 setClass("TunedInput",
   contains = "VIRTUAL",
   slots = c(grid = "ANY",
@@ -199,6 +204,11 @@ setClass("TunedModelRecipe",
 )
 
 
+setClass("TunedModeledRecipe",
+  contains = c("TunedModelRecipe", "ModeledRecipe")
+)
+
+
 #################### Model Fits ####################
 
 
