@@ -46,15 +46,6 @@ StackedModel <- function(..., control = MachineShop::settings("control"),
              init = .response_types),
     predictor_encoding = NA_character_,
     params = as.list(environment()),
-    predict = function(object, newdata, ...) {
-      pred <- 0
-      for (i in seq(object$base_fits)) {
-        base_pred <- predict(object$base_fits[[i]], newdata = newdata,
-                             times = object$times, type = "prob")
-        pred <- pred + object$weights[i] * base_pred
-      }
-      pred
-    },
     varimp = function(object, ...) NULL
   )
 
@@ -72,7 +63,7 @@ MLModelFunction(StackedModel) <- NULL
     num_learners <- length(base_learners)
     stack <- list()
     complete_cases <- TRUE
-    i <- structure(0, max = num_learners, names = class(x))
+    i <- structure(0, max = num_learners, names = x@name)
     while (i < attr(i, "max")) {
       i <- i + 1
       stack[[i]] <- resample(inputs, model = base_learners[[i]],
@@ -96,6 +87,17 @@ MLModelFunction(StackedModel) <- NULL
 }
 
 
+.predict.StackedModel <- function(x, object, newdata, ...) {
+  pred <- 0
+  for (i in seq(object$base_fits)) {
+    base_pred <- predict(object$base_fits[[i]], newdata = newdata,
+                         times = object$times, type = "prob")
+    pred <- pred + object$weights[i] * base_pred
+  }
+  pred
+}
+
+
 mean_stack_list <- function(x, weights) {
   pred <- 0
   for (i in seq(x)) pred <- pred + weights[i] * x[[i]]$Predicted
