@@ -66,7 +66,7 @@ MLModelFunction(SelectedModel) <- NULL
 .fit.SelectedModel <- function(x, inputs, ...) {
   models <- x@params$models
   trainbit <- resample_selection(models, identity, x@params, inputs,
-                                 class = class(x))
+                                 class = "SelectedModel")
   trainbit$grid <- tibble(Model = factor(seq(models)))
   model <- models[[trainbit$selected]]
   push(do.call(TrainBit, trainbit), fit(inputs, model = model))
@@ -179,7 +179,7 @@ MLModelFunction(TunedModel) <- NULL
                   inputs, model = getMLObject(params$model, "MLModel"))
   models <- expand_model(list(params$model, grid))
   trainbit <- resample_selection(models, identity, params, inputs,
-                                 class = class(x))
+                                 class = "TunedModel")
   trainbit$grid <- tibble(Model = grid)
   model <- models[[trainbit$selected]]
   push(do.call(TrainBit, trainbit), fit(inputs, model = model))
